==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_fields/BLOCKVENDOR_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour BLOCKVENDOR_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="BLOCKVENDOR_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VENDORNUM"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VENDORNAME" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEFAULTMP2VENDORNAME" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VENDORURL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VENDORNOTES" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BLOCKVENDOR_Type", propOrder = {
    "vendornum",
    "vendorname",
    "defaultmp2VENDORNAME",
    "vendorurl",
    "vendornotes"
})
public class BLOCKVENDOR_Type {

    @XmlElement(name = "VENDORNUM", required = true)
    protected String vendornum;
    @XmlElement(name = "VENDORNAME")
    protected String vendorname;
    @XmlElement(name = "DEFAULTMP2VENDORNAME")
    protected String defaultmp2VENDORNAME;
    @XmlElement(name = "VENDORURL")
    protected String vendorurl;
    @XmlElement(name = "VENDORNOTES")
    protected String vendornotes;

    /**
     * Obtient la valeur de la propriété vendornum.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVENDORNUM() {
        return vendornum;
    }

    /**
     * Définit la valeur de la propriété vendornum.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVENDORNUM(String value) {
        this.vendornum = value;
    }

    /**
     * Obtient la valeur de la propriété vendorname.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVENDORNAME() {
        return vendorname;
    }

    /**
     * Définit la valeur de la propriété vendorname.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVENDORNAME(String value) {
        this.vendorname = value;
    }

    /**
     * Obtient la valeur de la propriété defaultmp2VENDORNAME.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDEFAULTMP2VENDORNAME() {
        return defaultmp2VENDORNAME;
    }

    /**
     * Définit la valeur de la propriété defaultmp2VENDORNAME.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDEFAULTMP2VENDORNAME(String value) {
        this.defaultmp2VENDORNAME = value;
    }

    /**
     * Obtient la valeur de la propriété vendorurl.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVENDORURL() {
        return vendorurl;
    }

    /**
     * Définit la valeur de la propriété vendorurl.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVENDORURL(String value) {
        this.vendorurl = value;
    }

    /**
     * Obtient la valeur de la propriété vendornotes.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVENDORNOTES() {
        return vendornotes;
    }

    /**
     * Définit la valeur de la propriété vendornotes.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVENDORNOTES(String value) {
        this.vendornotes = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/BLOCKVENDOR_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for BLOCKVENDOR_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="BLOCKVENDOR_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VENDORNUM"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VENDORNAME" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEFAULTMP2VENDORNAME" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VENDORURL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VENDORNOTES" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BLOCKVENDOR_Type", propOrder = {
    "vendornum",
    "vendorname",
    "defaultmp2VENDORNAME",
    "vendorurl",
    "vendornotes"
})
public class BLOCKVENDOR_Type {

    @XmlElement(name = "VENDORNUM", required = true)
    protected String vendornum;
    @XmlElement(name = "VENDORNAME")
    protected String vendorname;
    @XmlElement(name = "DEFAULTMP2VENDORNAME")
    protected String defaultmp2VENDORNAME;
    @XmlElement(name = "VENDORURL")
    protected String vendorurl;
    @XmlElement(name = "VENDORNOTES")
    protected String vendornotes;

    /**
     * Gets the value of the vendornum property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVENDORNUM() {
        return vendornum;
    }

    /**
     * Sets the value of the vendornum property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVENDORNUM(String value) {
        this.vendornum = value;
    }

    /**
     * Gets the value of the vendorname property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVENDORNAME() {
        return vendorname;
    }

    /**
     * Sets the value of the vendorname property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVENDORNAME(String value) {
        this.vendorname = value;
    }

    /**
     * Gets the value of the defaultmp2VENDORNAME property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDEFAULTMP2VENDORNAME() {
        return defaultmp2VENDORNAME;
    }

    /**
     * Sets the value of the defaultmp2VENDORNAME property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDEFAULTMP2VENDORNAME(String value) {
        this.defaultmp2VENDORNAME = value;
    }

    /**
     * Gets the value of the vendorurl property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVENDORURL() {
        return vendorurl;
    }

    /**
     * Sets the value of the vendorurl property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVENDORURL(String value) {
        this.vendorurl = value;
    }

    /**
     * Gets the value of the vendornotes property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVENDORNOTES() {
        return vendornotes;
    }

    /**
     * Sets the value of the vendornotes property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVENDORNOTES(String value) {
        this.vendornotes = value;
    }

}
